@@ -154,12 +154,12 @@ static struct _GvmPromptButton GVM_BUTTONS_AUTORUN[] = {
 
 static struct _GvmPromptButton GVM_BUTTONS_CAMERA[] = {
 	{ N_("_Ignore"), NULL, GTK_RESPONSE_CANCEL },
-	{ N_("_Open Folder"), NULL, GVM_RESPONSE_BROWSE },
 	{ N_("Import _Photos"), NULL, GVM_RESPONSE_IMPORT_PHOTOS },
 };
 
-static struct _GvmPromptButton GVM_BUTTONS_PTP_CAMERA[] = {
+static struct _GvmPromptButton GVM_BUTTONS_STORAGE_CAMERA[] = {
 	{ N_("_Ignore"), NULL, GTK_RESPONSE_CANCEL },
+	{ N_("_Open Folder"), NULL, GVM_RESPONSE_BROWSE },
 	{ N_("Import _Photos"), NULL, GVM_RESPONSE_IMPORT_PHOTOS },
 };
 
@@ -189,7 +189,7 @@ static struct _GvmPromptButton GVM_BUTTONS_BURN_DVD[] = {
 typedef enum {
 	GVM_PROMPT_AUTORUN,
 	GVM_PROMPT_IMPORT_CAMERA,
-	GVM_PROMPT_IMPORT_PTP_CAMERA,
+	GVM_PROMPT_IMPORT_STORAGE_CAMERA,
 	GVM_PROMPT_IMPORT_PHOTOS,
 	GVM_PROMPT_IPOD_PHOTO,
 	GVM_PROMPT_CDA_EXTRA,
@@ -247,12 +247,12 @@ static struct {
 	  N_("There are photos on the camera. Would you like to add these pictures to your album?"), FALSE, FALSE,
 	  GCONF_ROOT "prompts/camera_import_photos", N_("_Always perform this action") },
 	{ 0, "applets-screenshooter", NULL,
-	  GVM_BUTTONS_PTP_CAMERA, G_N_ELEMENTS (GVM_BUTTONS_PTP_CAMERA),
+	  GVM_BUTTONS_STORAGE_CAMERA, G_N_ELEMENTS (GVM_BUTTONS_STORAGE_CAMERA),
 	  GVM_RESPONSE_IMPORT_PHOTOS,
 	  N_("Camera Import"),
 	  N_("A camera has been detected."),
 	  N_("There are photos on the camera. Would you like to add these pictures to your album?"), FALSE, FALSE,
-	  GCONF_ROOT "prompts/ptp_camera_import_photos", N_("_Always perform this action") },
+	  GCONF_ROOT "prompts/storage_camera_import_photos", N_("_Always perform this action") },
 	{ 0, "applets-screenshooter", NULL,
 	  GVM_BUTTONS_CAMERA, G_N_ELEMENTS (GVM_BUTTONS_CAMERA),
 	  GVM_RESPONSE_IMPORT_PHOTOS,
@@ -775,12 +775,12 @@ gvm_check_vcd (const char *udi, const char *device, const char *mount_point)
 }
 
 /*
- * gvm_udi_is_camera - checks if the udi is a camera device
+ * gvm_udi_is_storage_camera - checks if the udi is a mass-storage camera device
  *
  * Returns TRUE if the device is a camera or FALSE otherwise.
  */
 static gboolean
-gvm_udi_is_camera (const char *udi)
+gvm_udi_is_storage_camera (const char *udi)
 {
 	char *storage_device = NULL, *physical_device = NULL;
 	gboolean is_camera = FALSE;
@@ -813,15 +813,16 @@ gvm_udi_is_camera (const char *udi)
 }
 
 /*
- * gvm_udi_is_ptp_camera - checks if the udi is a PTP camera device
+ * gvm_udi_is_camera - checks if the udi is a supported non-mass-storage camera device
  *
- * Returns TRUE if the device is a PTP camera with libgphoto2 support or FALSE otherwise.
+ * Returns TRUE if the device is a camera with libgphoto2 support or FALSE otherwise.
  */
 static gboolean
-gvm_udi_is_ptp_camera (const char *udi)
+gvm_udi_is_camera (const char *udi)
 {
-	gboolean is_ptp_camera = FALSE;
+	gboolean is_camera = FALSE;
 	char *access_method;
+	char *driver;
 	
 #if 0
 	/* Note: this query is not necessary atm because our only caller already has this info */
@@ -832,14 +833,40 @@ gvm_udi_is_ptp_camera (const char *udi)
 	if (!(access_method = libhal_device_get_property_string (hal_ctx, udi, "camera.access_method", NULL)))
 		return FALSE;
 	
-	if (!strcmp (access_method, "ptp")) {
-		dbg ("PTP Camera detected: %s\n", udi);
-		is_ptp_camera = TRUE;
+	if (!strcmp (access_method, "storage")) {
+		/* we only want to match non-storage cameras */
+		is_camera = FALSE;
+		goto done;
+	} else if (!strcmp (access_method, "ptp")) {
+		/* ptp cameras are supported by libgphoto2 always */
+		is_camera = TRUE;
+		goto done;
+	} else if (!strcmp (access_method, "libgphoto2")) {
+		/* user has an old install of the libgphoto2 fdi files */
+		warn ("Please update your libgphoto2 package as the fdi files are outdated!\n");
+		if ((driver = libhal_device_get_property_string (hal_ctx, udi, "info.linux.driver", NULL))) {
+			/* the old fdi files marked everything as access_method="libgphoto2" so check that
+			 * this is a non-mass-storage camera */
+			if (!strcmp (driver, "usb-storage"))
+				is_camera = FALSE;
+		} else {
+			is_camera = TRUE;
+		}
+		
+		libhal_free_string (driver);
+		
+		goto done;
 	}
 	
+	dbg ("Non Mass-Storage Camera detected: %s\n", udi);
+	
+	is_camera = libhal_device_get_property_bool (hal_ctx, udi, "camera.libgphoto2.support", NULL);
+	
+ done:
+	
 	libhal_free_string (access_method);
 	
-	return is_ptp_camera;
+	return is_camera;
 }
 
 /*
@@ -1109,7 +1136,7 @@ gvm_udi_is_subfs_mount (const char *udi)
 }
 
 static void
-import_camera_cb (GvmPromptCtx *ctx, int action)
+import_storage_camera_cb (GvmPromptCtx *ctx, int action)
 {
 	switch (action) {
 	case GVM_RESPONSE_IMPORT_PHOTOS:
@@ -1168,8 +1195,8 @@ gvm_device_mounted (const char *udi)
 	}
 	
 	/* this is where the magic happens */
-	if (config.autophoto && gvm_udi_is_camera (udi)) {
-		ctx = gvm_prompt_ctx_new (GVM_PROMPT_IMPORT_CAMERA, import_camera_cb, udi, device, mount_point, NULL);
+	if (config.autophoto && gvm_udi_is_storage_camera (udi)) {
+		ctx = gvm_prompt_ctx_new (GVM_PROMPT_IMPORT_STORAGE_CAMERA, import_storage_camera_cb, udi, device, mount_point, NULL);
 		gvm_prompt (ctx, 0, NULL);
 	} else if (config.autoipod && gvm_udi_is_ipod (udi)) {
 		char *ipod_control;
@@ -1504,7 +1531,7 @@ gvm_automount_enabled (const char *udi)
 }
 
 static void
-import_ptp_camera_cb (GvmPromptCtx *ctx, int action)
+import_camera_cb (GvmPromptCtx *ctx, int action)
 {
 	if (action == GVM_RESPONSE_IMPORT_PHOTOS)
 		gvm_run_camera (ctx->udi, NULL, NULL);
@@ -1526,9 +1553,9 @@ block_device_added (const char *udi, const char *capability __attribute__((__unu
 	char *fsusage = NULL, *device = NULL, *storage_device = NULL;
 	DBusError error;
 	int mountable;
-
+	
 	dbus_error_init (&error);
-
+	
 	/* is this a mountable volume? */
 	if (!(mountable = libhal_device_get_property_bool (hal_ctx, udi, "block.is_volume", NULL))) {
 		dbg ("not a mountable volume: %s\n", udi);
@@ -1594,13 +1621,13 @@ camera_device_added (const char *udi, const char *capability __attribute__((__un
 {
 	GvmPromptCtx *ctx;
 	
-	if (!gvm_udi_is_ptp_camera (udi))
+	if (!gvm_udi_is_camera (udi))
 		return FALSE;
 	
 	if (!(config.autophoto && config.autophoto_command))
 		return TRUE;
 	
-	ctx = gvm_prompt_ctx_new (GVM_PROMPT_IMPORT_PTP_CAMERA, import_ptp_camera_cb, udi, NULL, NULL, NULL);
+	ctx = gvm_prompt_ctx_new (GVM_PROMPT_IMPORT_CAMERA, import_camera_cb, udi, NULL, NULL, NULL);
 	gvm_prompt (ctx, 0, NULL);
 	
 	return TRUE;
