@@ -43,14 +43,16 @@ enum {
 	AUTOMOUNT_MEDIA,
 	AUTOMOUSE,
 	AUTOMOUSE_COMMAND,
-	AUTOPALMSYNC,
-	AUTOPALMSYNC_COMMAND,
 	AUTOPHOTO,
 	AUTOPHOTO_COMMAND,
+	AUTOPILOT,
+	AUTOPILOT_COMMAND,
 	AUTOPLAY_CDA,
 	AUTOPLAY_CDA_COMMAND,
 	AUTOPLAY_DVD,
 	AUTOPLAY_DVD_COMMAND,
+	AUTOPOCKETPC,
+	AUTOPOCKETPC_COMMAND,
 	AUTOPRINTER,
 	AUTOPRINTER_COMMAND,
 	AUTORUN,
@@ -82,14 +84,16 @@ static struct {
 	{ GCONF_ROOT "automount_media",           TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "automouse",                 TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "automouse_command",         TYPE_STRING, NULL, FALSE },
-	{ GCONF_ROOT "autopalmsync",              TYPE_BOOL,   NULL, TRUE  },
-	{ GCONF_ROOT "autopalmsync_command",      TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autophoto",                 TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autophoto_command",         TYPE_STRING, NULL, FALSE },
+	{ GCONF_ROOT "autopalmsync",              TYPE_BOOL,   NULL, TRUE  },
+	{ GCONF_ROOT "autopalmsync_command",      TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoplay_cda",              TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoplay_cda_command",      TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoplay_dvd",              TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoplay_dvd_command",      TYPE_STRING, NULL, FALSE },
+	{ GCONF_ROOT "autopocketpc",              TYPE_BOOL,   NULL, TRUE  },
+	{ GCONF_ROOT "autopocketpc_command",      TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoprinter",               TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoprinter_command",       TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autorun",                   TYPE_BOOL,   NULL, TRUE  },
@@ -299,6 +303,8 @@ show_props (void)
 	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-mime-video");
 	icon = glade_xml_get_widget (xml, "palm_image");
 	set_icon (GTK_IMAGE (icon), icon_theme, "palm-pilot");
+	icon = glade_xml_get_widget (xml, "pocketpc_image");
+	set_icon (GTK_IMAGE (icon), icon_theme, "palm-pilot");
 	
 	gtk_window_set_default_icon_name ("gnome-dev-cdrom");
 	
